==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneCloseEventArgsDetailDescriptionMetadata } from "./WebPaneCloseEventArgsDetailDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneCloseEventArgsDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneCloseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaneCloseEventArgsDescriptionMetadata.a);
        WebPaneCloseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneCloseEventArgsDetail");
    };
    WebPaneCloseEventArgsDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDescriptionMetadata.b(a);
        a.ac("WebPaneCloseEventArgs", function () { return new WebPaneCloseEventArgsDescription(); });
        a.ab("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneCloseEventArgsDetailDescriptionMetadata } from "./WebPaneCloseEventArgsDetailDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneCloseEventArgsDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneCloseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneCloseEventArgsDescriptionMetadata.a);
        WebPaneCloseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneCloseEventArgsDetail");
    };
    WebPaneCloseEventArgsDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDescriptionMetadata.b(a);
        a.ae("WebPaneCloseEventArgs", function () { return new WebPaneCloseEventArgsDescription(); });
        a.ad("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDescriptionMetadata };
